@@ -49,6 +49,7 @@ class TransformerEmbedding(ABCEmbedding):
 
 
         self.with_pool = kwargs.get("with_pool",False)
+        self.num_hidden_layers = kwargs.get("num_hidden_layers",12)
         # with open(config_path, 'r') as f:
         #     config = json.loads(f.read())
         #     if 'max_position' in config:
@@ -61,12 +62,14 @@ class TransformerEmbedding(ABCEmbedding):
 
 
     def build_embedding_model(self) -> None:
+        import tensorflow.keras.backend as K
         if self.model_type == 'electra':
             bert_model = build_transformer_model(config_path=self.config_path,
                                                  checkpoint_path=self.checkpoint_path,
                                                  model=self.model_type,
                                                  application=self.bert_application,
                                                  keep_tokens=self.keep_tokens,  # 只保留keep_tokens中的字，精简原字表
+                                                 prefix="bert_encoder/"
                                                  )
         else:
             bert_model = build_transformer_model(config_path=self.config_path,
@@ -74,7 +77,9 @@ class TransformerEmbedding(ABCEmbedding):
                                                  model=self.model_type,
                                                  application=self.bert_application,
                                                  keep_tokens=self.keep_tokens,  # 只保留keep_tokens中的字，精简原字表
-                                                 with_pool = self.with_pool
+                                                 with_pool = self.with_pool,
+                                                 num_hidden_layers = self.num_hidden_layers,
+                                                 prefix="bert_encoder/"
                                                  )
         self.embed_model = bert_model
         self.embedding_size = bert_model.output.shape[-1]
